pub struct TnuaBuiltinClimb {
pub anchor: Vector3,
pub desired_vec_to_anchor: Vector3,
pub desired_climb_motion: Vector3,
pub desired_forward: Option<Dir3>,
pub hard_stop_up: Option<Vector3>,
pub hard_stop_down: Option<Vector3>,
}Expand description
An action for climbing on things.
Fields
anchor: Vector3A point on the climbed entity where the character touches it.
Note that this does not actually have to be on any actual collider. It can be a point in the middle of the air, and the action will cause the character to pretend there is something there and climb on it.
desired_vec_to_anchor: Vector3The position of the anchor compared to the character.
The action will try to maintain this horizontal relative position.
desired_climb_motion: Vector3The direction (in the world space) and speed to climb at (move up/down the entity)
desired_forward: Option<Dir3>Force the character to face in a particular direction.
hard_stop_up: Option<Vector3>Prevent the character from climbing above this point.
Tip: use
probe_extent_from_closest_point
to find this point.
hard_stop_down: Option<Vector3>Prevent the character from climbing below this point.
Tip: use
probe_extent_from_closest_point
to find this point.