pub struct TnuaBuiltinKnockbackConfig {
pub no_push_timeout: f32,
pub barrier_strength_diminishing: Float,
pub acceleration_limit: Float,
pub air_acceleration_limit: Float,
}Fields
no_push_timeout: f32Timeout (in seconds) for abandoning a Pushover boundary that no longer gets pushed.
barrier_strength_diminishing: FloatAn exponent for controlling the shape of the Pushover barrier diminishing.
For best results, set it to values larger than 1.0.
acceleration_limit: FloatAcceleration cap when pushing against the Pushover barrier.
In practice this will be averaged with the acceleration the basis tries to apply (weighted
by a function of the Pushover boundary penetration percentage and
barrier_strength_diminishing) so the actual
acceleration limit will higher than that.
air_acceleration_limit: FloatAcceleration cap when pushing against the Pushover barrier while in the air.
In practice this will be averaged with the acceleration the basis tries to apply (weighted
by a function of the Pushover boundary penetration percentage and
barrier_strength_diminishing) so the actual
acceleration limit will higher than that.